@@ -20,11 +20,9 @@ import wandio.swift
 
 class Reader(wandio.file.GenericReader):
 
-    def __init__(self, filename, options=None):
+    def __init__(self, filename, mode="r", options=None):
         self.filename = filename
 
-        is_binary_file = True if filename.endswith(".gz") or filename.endswith(".bz2") else False
-
         # check for the transport types first (HTTP, Swift, Simple)
 
         # is this Swift
@@ -41,7 +39,10 @@ class Reader(wandio.file.GenericReader):
 
         # then it must be a simple local file
         else:
-            fh = wandio.file.SimpleReader(self.filename, is_binary=is_binary_file)
+            # default reading as binary mode for .gz and .bz2 files
+            if filename.endswith(".gz") or filename.endswith(".bz2"):
+                mode = "rb"
+            fh = wandio.file.SimpleReader(self.filename, mode=mode)
 
         assert fh
 
@@ -65,7 +66,7 @@ class Reader(wandio.file.GenericReader):
 # TODO: refactor Reader and Writer
 class Writer(wandio.file.GenericWriter):
 
-    def __init__(self, filename, options=None):
+    def __init__(self, filename, mode="w", options=None):
         self.filename = filename
 
         is_binary_file = True if filename.endswith(".gz") or filename.endswith(".bz2") else False
@@ -81,7 +82,9 @@ class Writer(wandio.file.GenericWriter):
 
         # then it must be a simple local file
         else:
-            fh = wandio.file.SimpleWriter(self.filename, is_binary=is_binary_file)
+            if is_binary_file:
+                mode = "wb"
+            fh = wandio.file.SimpleWriter(self.filename, mode=mode)
 
         assert fh
 
@@ -102,13 +105,13 @@ class Writer(wandio.file.GenericWriter):
         super(Writer, self).__init__(fh)
 
 
-def wandio_open(filename, mode="r"):
-    if mode == "r":
-        return Reader(filename)
-    elif mode == "w":
-        return Writer(filename)
+def wandio_open(filename, mode="r", options=None):
+    if mode in ["r", "rb"]:
+        return Reader(filename, mode, options)
+    elif mode in ["w", "wb"]:
+        return Writer(filename, mode, options)
     else:
-        raise ValueError("Invalid mode. Mode must be either 'r' or 'w'")
+        raise ValueError("Invalid mode. Mode must be either 'r'/'rb' or 'w'/'wb'")
 
 
 def wandio_stat(filename):
@@ -150,11 +153,14 @@ def read_main():
                         help="Force use of next (for testing)")
 
     parser.add_argument('files', nargs='+', help='Files to read from')
+    parser.add_argument('-m', '--file-mode', required=False,
+                        type=str, default='r',
+                        help="Open files using this file mode")
 
     opts = vars(parser.parse_args())
 
     for filename in opts['files']:
-        with Reader(filename) as fh:
+        with Reader(filename, mode=opts['file_mode']) as fh:
             if opts['use_next']:
                 # sys.stderr.write("Reading using 'next'\n")
                 for line in fh:
